@@ -22,8 +22,8 @@ using namespace Kontact;
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
-#include <KService>
-#include <KServiceTypeTrader>
+#include <KPluginLoader>
+#include <KPluginMetaData>
 #include <KWindowSystem>
 
 #include <QCommandLineParser>
@@ -31,7 +31,10 @@ using namespace Kontact;
 #include <QDBusConnectionInterface>
 
 #include <iostream>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <kdelibs4configmigrator.h>
+#endif
 using namespace std;
 
 static const char version[] = KONTACT_VERSION;
@@ -71,17 +74,21 @@ private:
 
 static void listPlugins()
 {
-    const KService::List offers =
-        KServiceTypeTrader::self()->query(QStringLiteral("Kontact/Plugin"), QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
-    const KService::List::ConstIterator end(offers.end());
-    for (KService::List::ConstIterator it = offers.begin(); it != end; ++it) {
-        KService::Ptr service = (*it);
+    const QVector<KPluginMetaData> pluginMetaDatas = KPluginLoader::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
+        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+    });
+
+    for (const KPluginMetaData &plugin : pluginMetaDatas) {
         // skip summary only plugins
-        QVariant var = service->property(QStringLiteral("X-KDE-KontactPluginHasPart"));
-        if (var.isValid() && var.toBool() == false) {
-            continue;
+        if (plugin.rawData().contains(QLatin1String("X-KDE-KontactPluginHasPart"))) {
+            bool var = plugin.rawData().value(QStringLiteral("X-KDE-KontactPluginHasPart")).toBool();
+
+            if (!var) {
+                continue;
+            }
         }
-        cout << "lib name " << qPrintable(service->library().remove(QStringLiteral("kontact_"))) << endl;
+
+        cout << "lib name " << qPrintable(plugin.pluginId().remove(QStringLiteral("kontact_"))) << endl;
     }
 }
 
@@ -145,11 +152,12 @@ int main(int argc, char **argv)
     KontactApp app(argc, &argv);
 
     KCrash::initialize();
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kontact"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kontactrc") << QStringLiteral("kontact_summaryrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kontactui.rc"));
     migrate.migrate();
-
+#endif
     KAboutData about(QStringLiteral("kontact"),
                      i18n("Kontact"),
                      QLatin1String(version),
